@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 import sys
-sys.path.extend(['.', '..'])
+sys.path[0:0] = ['.', '..']
 
 import unittest
 
@@ -15,7 +15,7 @@ suite = unittest.TestLoader().loadTestsFromNames(
         'test_c_generator',
     ]
 )
-    
+
 testresult = unittest.TextTestRunner(verbosity=1).run(suite)
 sys.exit(0 if testresult.wasSuccessful() else 1)
 
